[Bug 64191] New: Applications not working with 7.0.100

2020-03-03 Thread bugzilla
https://bz.apache.org/bugzilla/show_bug.cgi?id=64191

Bug ID: 64191
   Summary: Applications not working with 7.0.100
   Product: Tomcat 7
   Version: 7.0.100
  Hardware: PC
OS: Linux
Status: NEW
  Severity: blocker
  Priority: P2
 Component: Catalina
  Assignee: dev@tomcat.apache.org
  Reporter: thomas.w...@gfk.com
  Target Milestone: ---

Hi,

we have several applications, which refuse to work with the 7.0.100 release.
The crazy thing is: There are no log outputs showing an failure. In
catalina.out we only see, that the application has started. Interestingly,
static files in the applications can be accessed, i.e. a "it Works" page. When
it come to Java files, they will obvioulsy not been executed, although we can
see in the logfile, that they have been registered. The applications also do
not produce any output - normally they log their start and stuff in a separate
logfile, but this will be kept untouched. 

It is very hard to find the issue, all I can say, the applications work with
7.0.99 like a charm, but not with 7.0.100

best

Thomas

-- 
You are receiving this mail because:
You are the assignee for the bug.
-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



[Bug 64191] Applications not working with 7.0.100

2020-03-03 Thread bugzilla
https://bz.apache.org/bugzilla/show_bug.cgi?id=64191

--- Comment #1 from Mark Thomas  ---
Probably the SCI regression that has already been fixed. Are you able to build
Tomcat 7.0.x from source to test the latest code?

-- 
You are receiving this mail because:
You are the assignee for the bug.
-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



[GitHub] [tomcat] markt-asf merged pull request #250: Fix semantics of get and set EnableSessionCreation

2020-03-03 Thread GitBox
markt-asf merged pull request #250: Fix semantics of get and set 
EnableSessionCreation
URL: https://github.com/apache/tomcat/pull/250
 
 
   


This is an automated message from the Apache Git Service.
To respond to the message, please log on to GitHub and use the
URL above to go to the specific comment.
 
For queries about this service, please contact Infrastructure at:
us...@infra.apache.org


With regards,
Apache Git Services

-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



[GitHub] [tomcat] markt-asf commented on issue #250: Fix semantics of get and set EnableSessionCreation

2020-03-03 Thread GitBox
markt-asf commented on issue #250: Fix semantics of get and set 
EnableSessionCreation
URL: https://github.com/apache/tomcat/pull/250#issuecomment-593827122
 
 
   LGTM. It is missing an entry in the change log. I'll add that.


This is an automated message from the Apache Git Service.
To respond to the message, please log on to GitHub and use the
URL above to go to the specific comment.
 
For queries about this service, please contact Infrastructure at:
us...@infra.apache.org


With regards,
Apache Git Services

-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



[tomcat] branch master updated: Fix semantics of get and set EnableSessionCreation

2020-03-03 Thread markt
This is an automated email from the ASF dual-hosted git repository.

markt pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/tomcat.git


The following commit(s) were added to refs/heads/master by this push:
 new 39a46bc  Fix semantics of get and set EnableSessionCreation
39a46bc is described below

commit 39a46bcc08bfd48970cd04eb129c6dff6b233bc4
Author: Alexander Scheel 
AuthorDate: Mon Mar 2 17:16:33 2020 -0500

Fix semantics of get and set EnableSessionCreation

Per the javadocs for SSLEngine, setEnableSessionCreation controls
whether or not new sessions are allowed to be created, or whether this
SSLEngine is restricted to resuming existing sessions. The default is
true, i.e., allow new sessions to be created. Because the OpenSSL
SSLEngine implementation does not limit the creation of new sessions,
getEnableSessionCreation should always return true, not false, and the
set operation should only yield an exception when the parameter is
false.

Signed-off-by: Alexander Scheel 
---
 java/org/apache/tomcat/util/net/openssl/LocalStrings.properties | 1 +
 java/org/apache/tomcat/util/net/openssl/OpenSSLEngine.java  | 7 ---
 2 files changed, 5 insertions(+), 3 deletions(-)

diff --git a/java/org/apache/tomcat/util/net/openssl/LocalStrings.properties 
b/java/org/apache/tomcat/util/net/openssl/LocalStrings.properties
index 2b5e31f..486f9ea 100644
--- a/java/org/apache/tomcat/util/net/openssl/LocalStrings.properties
+++ b/java/org/apache/tomcat/util/net/openssl/LocalStrings.properties
@@ -19,6 +19,7 @@ engine.engineClosed=Engine is closed
 engine.failedCipherSuite=Failed to enable cipher suite [{0}]
 engine.inboundClose=Inbound closed before receiving peer's close_notify
 engine.invalidBufferArray=offset: [{0}], length: [{1}] (expected: offset <= 
offset + length <= srcs.length [{2}])
+engine.noRestrictSessionCreation=OpenSslEngine does not permit restricting the 
engine to only resuming existing sessions
 engine.noSSLContext=No SSL context
 engine.noSession=SSL session ID not available
 engine.nullBuffer=Null buffer
diff --git a/java/org/apache/tomcat/util/net/openssl/OpenSSLEngine.java 
b/java/org/apache/tomcat/util/net/openssl/OpenSSLEngine.java
index 04f8558..3607b01 100644
--- a/java/org/apache/tomcat/util/net/openssl/OpenSSLEngine.java
+++ b/java/org/apache/tomcat/util/net/openssl/OpenSSLEngine.java
@@ -1117,14 +1117,15 @@ public final class OpenSSLEngine extends SSLEngine 
implements SSLUtil.ProtocolIn
 
 @Override
 public void setEnableSessionCreation(boolean b) {
-if (b) {
-throw new UnsupportedOperationException();
+if (!b) {
+String msg = sm.getString("engine.noRestrictSessionCreation");
+throw new UnsupportedOperationException(msg);
 }
 }
 
 @Override
 public boolean getEnableSessionCreation() {
-return false;
+return true;
 }
 
 @Override


-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



[tomcat] branch master updated: Update changelog

2020-03-03 Thread markt
This is an automated email from the ASF dual-hosted git repository.

markt pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/tomcat.git


The following commit(s) were added to refs/heads/master by this push:
 new 5b2cd9c  Update changelog
5b2cd9c is described below

commit 5b2cd9ca17625f641072cdd77a05f9d05893cae8
Author: Mark Thomas 
AuthorDate: Tue Mar 3 08:28:19 2020 +

Update changelog
---
 webapps/docs/changelog.xml | 5 +
 1 file changed, 5 insertions(+)

diff --git a/webapps/docs/changelog.xml b/webapps/docs/changelog.xml
index b7a7fa3..66a1629 100644
--- a/webapps/docs/changelog.xml
+++ b/webapps/docs/changelog.xml
@@ -124,6 +124,11 @@
 and allow the other channels using the connection to continue. Based on
 a suggestion from Alejandro Anadon. (markt)
   
+  
+Correct the semantics of getEnableSessionCreation and
+setEnableSessionCreation for OpenSSLEngine.
+Pull request provided by Alexander Scheel. (markt)
+  
 
   
   


-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



[Bug 64089] Resource paths resolve symlinks

2020-03-03 Thread bugzilla
https://bz.apache.org/bugzilla/show_bug.cgi?id=64089

Marvin Fröhlich  changed:

   What|Removed |Added

 Resolution|FIXED   |---
 Status|RESOLVED|REOPENED

--- Comment #10 from Marvin Fröhlich  ---
I'm trying to get this to work. But none of my attempts was successful.

$CATALINA_BASE points to "/opt/tomcat/current"



The above leads to a MalformedURLException:
java.net.MalformedURLException: no protocol:
${catalina.base}/foo/bar/myentity.xml



The above leads to:
java.net.UnknownHostException: ${catalina.base}



And this one leads to:
Parse error in application web.xml file at
[file:/path/to/webapp/WEB-INF/web.xml]

I'm on Tomcat 9.0.31. What am I doing wrong?

I should mention, that still my webapp folders under catalina-base/webapps are
all symlinks.

-- 
You are receiving this mail because:
You are the assignee for the bug.
-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



[Bug 64089] Resource paths resolve symlinks

2020-03-03 Thread bugzilla
https://bz.apache.org/bugzilla/show_bug.cgi?id=64089

--- Comment #11 from Marvin Fröhlich  ---
I also tried



which led to:
java.io.FileNotFoundException: ${catalina.base}/foo/bar/myentity.xml (Datei
oder Verzeichnis nicht gefunden)

-- 
You are receiving this mail because:
You are the assignee for the bug.
-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



[tomcat] branch 9.0.x updated: Fix semantics of get and set EnableSessionCreation

2020-03-03 Thread markt
This is an automated email from the ASF dual-hosted git repository.

markt pushed a commit to branch 9.0.x
in repository https://gitbox.apache.org/repos/asf/tomcat.git


The following commit(s) were added to refs/heads/9.0.x by this push:
 new 3938c2f  Fix semantics of get and set EnableSessionCreation
3938c2f is described below

commit 3938c2fc163bed7c382795a50c70af1f5ca1b25e
Author: Alexander Scheel 
AuthorDate: Mon Mar 2 17:16:33 2020 -0500

Fix semantics of get and set EnableSessionCreation

Per the javadocs for SSLEngine, setEnableSessionCreation controls
whether or not new sessions are allowed to be created, or whether this
SSLEngine is restricted to resuming existing sessions. The default is
true, i.e., allow new sessions to be created. Because the OpenSSL
SSLEngine implementation does not limit the creation of new sessions,
getEnableSessionCreation should always return true, not false, and the
set operation should only yield an exception when the parameter is
false.

Signed-off-by: Alexander Scheel 
---
 java/org/apache/tomcat/util/net/openssl/LocalStrings.properties | 1 +
 java/org/apache/tomcat/util/net/openssl/OpenSSLEngine.java  | 7 ---
 webapps/docs/changelog.xml  | 5 +
 3 files changed, 10 insertions(+), 3 deletions(-)

diff --git a/java/org/apache/tomcat/util/net/openssl/LocalStrings.properties 
b/java/org/apache/tomcat/util/net/openssl/LocalStrings.properties
index 2b5e31f..486f9ea 100644
--- a/java/org/apache/tomcat/util/net/openssl/LocalStrings.properties
+++ b/java/org/apache/tomcat/util/net/openssl/LocalStrings.properties
@@ -19,6 +19,7 @@ engine.engineClosed=Engine is closed
 engine.failedCipherSuite=Failed to enable cipher suite [{0}]
 engine.inboundClose=Inbound closed before receiving peer's close_notify
 engine.invalidBufferArray=offset: [{0}], length: [{1}] (expected: offset <= 
offset + length <= srcs.length [{2}])
+engine.noRestrictSessionCreation=OpenSslEngine does not permit restricting the 
engine to only resuming existing sessions
 engine.noSSLContext=No SSL context
 engine.noSession=SSL session ID not available
 engine.nullBuffer=Null buffer
diff --git a/java/org/apache/tomcat/util/net/openssl/OpenSSLEngine.java 
b/java/org/apache/tomcat/util/net/openssl/OpenSSLEngine.java
index 04f8558..3607b01 100644
--- a/java/org/apache/tomcat/util/net/openssl/OpenSSLEngine.java
+++ b/java/org/apache/tomcat/util/net/openssl/OpenSSLEngine.java
@@ -1117,14 +1117,15 @@ public final class OpenSSLEngine extends SSLEngine 
implements SSLUtil.ProtocolIn
 
 @Override
 public void setEnableSessionCreation(boolean b) {
-if (b) {
-throw new UnsupportedOperationException();
+if (!b) {
+String msg = sm.getString("engine.noRestrictSessionCreation");
+throw new UnsupportedOperationException(msg);
 }
 }
 
 @Override
 public boolean getEnableSessionCreation() {
-return false;
+return true;
 }
 
 @Override
diff --git a/webapps/docs/changelog.xml b/webapps/docs/changelog.xml
index 52ff0ff..38c436d 100644
--- a/webapps/docs/changelog.xml
+++ b/webapps/docs/changelog.xml
@@ -123,6 +123,11 @@
 and allow the other channels using the connection to continue. Based on
 a suggestion from Alejandro Anadon. (markt)
   
+  
+Correct the semantics of getEnableSessionCreation and
+setEnableSessionCreation for OpenSSLEngine.
+Pull request provided by Alexander Scheel. (markt)
+  
 
   
   


-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



[tomcat] branch 8.5.x updated: Fix semantics of get and set EnableSessionCreation

2020-03-03 Thread markt
This is an automated email from the ASF dual-hosted git repository.

markt pushed a commit to branch 8.5.x
in repository https://gitbox.apache.org/repos/asf/tomcat.git


The following commit(s) were added to refs/heads/8.5.x by this push:
 new 644d59a  Fix semantics of get and set EnableSessionCreation
644d59a is described below

commit 644d59a717b3a5017d07a6d67eab364e3fc89527
Author: Alexander Scheel 
AuthorDate: Mon Mar 2 17:16:33 2020 -0500

Fix semantics of get and set EnableSessionCreation

Per the javadocs for SSLEngine, setEnableSessionCreation controls
whether or not new sessions are allowed to be created, or whether this
SSLEngine is restricted to resuming existing sessions. The default is
true, i.e., allow new sessions to be created. Because the OpenSSL
SSLEngine implementation does not limit the creation of new sessions,
getEnableSessionCreation should always return true, not false, and the
set operation should only yield an exception when the parameter is
false.

Signed-off-by: Alexander Scheel 
---
 java/org/apache/tomcat/util/net/openssl/LocalStrings.properties | 1 +
 java/org/apache/tomcat/util/net/openssl/OpenSSLEngine.java  | 7 ---
 webapps/docs/changelog.xml  | 5 +
 3 files changed, 10 insertions(+), 3 deletions(-)

diff --git a/java/org/apache/tomcat/util/net/openssl/LocalStrings.properties 
b/java/org/apache/tomcat/util/net/openssl/LocalStrings.properties
index 2b5e31f..486f9ea 100644
--- a/java/org/apache/tomcat/util/net/openssl/LocalStrings.properties
+++ b/java/org/apache/tomcat/util/net/openssl/LocalStrings.properties
@@ -19,6 +19,7 @@ engine.engineClosed=Engine is closed
 engine.failedCipherSuite=Failed to enable cipher suite [{0}]
 engine.inboundClose=Inbound closed before receiving peer's close_notify
 engine.invalidBufferArray=offset: [{0}], length: [{1}] (expected: offset <= 
offset + length <= srcs.length [{2}])
+engine.noRestrictSessionCreation=OpenSslEngine does not permit restricting the 
engine to only resuming existing sessions
 engine.noSSLContext=No SSL context
 engine.noSession=SSL session ID not available
 engine.nullBuffer=Null buffer
diff --git a/java/org/apache/tomcat/util/net/openssl/OpenSSLEngine.java 
b/java/org/apache/tomcat/util/net/openssl/OpenSSLEngine.java
index 04f8558..3607b01 100644
--- a/java/org/apache/tomcat/util/net/openssl/OpenSSLEngine.java
+++ b/java/org/apache/tomcat/util/net/openssl/OpenSSLEngine.java
@@ -1117,14 +1117,15 @@ public final class OpenSSLEngine extends SSLEngine 
implements SSLUtil.ProtocolIn
 
 @Override
 public void setEnableSessionCreation(boolean b) {
-if (b) {
-throw new UnsupportedOperationException();
+if (!b) {
+String msg = sm.getString("engine.noRestrictSessionCreation");
+throw new UnsupportedOperationException(msg);
 }
 }
 
 @Override
 public boolean getEnableSessionCreation() {
-return false;
+return true;
 }
 
 @Override
diff --git a/webapps/docs/changelog.xml b/webapps/docs/changelog.xml
index e0dcf68..75b8809 100644
--- a/webapps/docs/changelog.xml
+++ b/webapps/docs/changelog.xml
@@ -129,6 +129,11 @@
 and allow the other channels using the connection to continue. Based on
 a suggestion from Alejandro Anadon. (markt)
   
+  
+Correct the semantics of getEnableSessionCreation and
+setEnableSessionCreation for OpenSSLEngine.
+Pull request provided by Alexander Scheel. (markt)
+  
 
   
   


-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



[Bug 64189] Expose Context Version as Servlet Context attribute

2020-03-03 Thread bugzilla
https://bz.apache.org/bugzilla/show_bug.cgi?id=64189

--- Comment #3 from nicola.iso...@gmail.com ---
Many thanks.

diff --git a/java/org/apache/catalina/users/MemoryUserDatabase.java 
b/java/org/apache/catalina/users/MemoryUserDatabase.java
index 778a1a2..7c81f11 100644
--- a/java/org/apache/catalina/users/MemoryUserDatabase.java
+++ b/java/org/apache/catalina/users/MemoryUserDatabase.java
@@ -17,6 +17,7 @@
 package org.apache.catalina.users;
 
 import java.io.File;
+import java.io.FileNotFoundException;
 import java.io.FileOutputStream;
 import java.io.IOException;
 import java.io.OutputStreamWriter;
@@ -683,6 +684,11 @@ public class MemoryUserDatabase implements UserDatabase {
 try {
 // Can't close a uConn directly. Have to do it like this.
 uConn.getInputStream().close();
+} catch (FileNotFoundException fnfe) {
+// The file doesn't exist.
+// This has been logged above. No need to log again.
+// Set the last modified time to avoid repeated log 
messages
+this.lastModified = 0;
 } catch (IOException ioe) {
 log.warn(sm.getString("memoryUserDatabase.fileClose", 
pathname), ioe);
 }
diff --git a/webapps/docs/changelog.xml b/webapps/docs/changelog.xml
index 66a1629..cf486e2 100644
--- a/webapps/docs/changelog.xml
+++ b/webapps/docs/changelog.xml
@@ -84,6 +84,11 @@
 support authentication persistence. Patch provided by Carsten Klein.
 (markt)
   
+  
+64184: Avoid repeated log messages if a
+MemoryUserDatabase is configured but the specified
+configuration file is missing. (markt)
+  
   
 64189: Expose the web application version String as a
 ServletContext attribute named


-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



[tomcat] branch 8.5.x updated: BZ 61484. Repeated log messages with missing tomcat-users.xml

2020-03-03 Thread markt
This is an automated email from the ASF dual-hosted git repository.

markt pushed a commit to branch 8.5.x
in repository https://gitbox.apache.org/repos/asf/tomcat.git


The following commit(s) were added to refs/heads/8.5.x by this push:
 new a9a94e3  BZ 61484. Repeated log messages with missing tomcat-users.xml
a9a94e3 is described below

commit a9a94e394a73b74e3937056e2dbba628f0211dc6
Author: Mark Thomas 
AuthorDate: Tue Mar 3 10:29:19 2020 +

BZ 61484. Repeated log messages with missing tomcat-users.xml

https://bz.apache.org/bugzilla/show_bug.cgi?id=64184
---
 java/org/apache/catalina/users/MemoryUserDatabase.java | 6 ++
 webapps/docs/changelog.xml | 5 +
 2 files changed, 11 insertions(+)

diff --git a/java/org/apache/catalina/users/MemoryUserDatabase.java 
b/java/org/apache/catalina/users/MemoryUserDatabase.java
index 45e846c..1f44202 100644
--- a/java/org/apache/catalina/users/MemoryUserDatabase.java
+++ b/java/org/apache/catalina/users/MemoryUserDatabase.java
@@ -17,6 +17,7 @@
 package org.apache.catalina.users;
 
 import java.io.File;
+import java.io.FileNotFoundException;
 import java.io.FileOutputStream;
 import java.io.IOException;
 import java.io.InputStream;
@@ -698,6 +699,11 @@ public class MemoryUserDatabase implements UserDatabase {
 try {
 // Can't close a uConn directly. Have to do it like this.
 uConn.getInputStream().close();
+} catch (FileNotFoundException fnfe) {
+// The file doesn't exist.
+// This has been logged above. No need to log again.
+// Set the last modified time to avoid repeated log 
messages
+this.lastModified = 0;
 } catch (IOException ioe) {
 log.warn(sm.getString("memoryUserDatabase.fileClose", 
pathname), ioe);
 }
diff --git a/webapps/docs/changelog.xml b/webapps/docs/changelog.xml
index 75b8809..61dba28 100644
--- a/webapps/docs/changelog.xml
+++ b/webapps/docs/changelog.xml
@@ -91,6 +91,11 @@
 support authentication persistence. Patch provided by Carsten Klein.
 (markt)
   
+  
+64184: Avoid repeated log messages if a
+MemoryUserDatabase is configured but the specified
+configuration file is missing. (markt)
+  
   
 64189: Expose the web application version String as a
 ServletContext attribute named


-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



[tomcat] branch 9.0.x updated: BZ 61484. Repeated log messages with missing tomcat-users.xml

2020-03-03 Thread markt
This is an automated email from the ASF dual-hosted git repository.

markt pushed a commit to branch 9.0.x
in repository https://gitbox.apache.org/repos/asf/tomcat.git


The following commit(s) were added to refs/heads/9.0.x by this push:
 new c2cf5a3  BZ 61484. Repeated log messages with missing tomcat-users.xml
c2cf5a3 is described below

commit c2cf5a33df93c33f812a12bb29acabeea0e974d1
Author: Mark Thomas 
AuthorDate: Tue Mar 3 10:29:19 2020 +

BZ 61484. Repeated log messages with missing tomcat-users.xml

https://bz.apache.org/bugzilla/show_bug.cgi?id=64184
---
 java/org/apache/catalina/users/MemoryUserDatabase.java | 6 ++
 webapps/docs/changelog.xml | 5 +
 2 files changed, 11 insertions(+)

diff --git a/java/org/apache/catalina/users/MemoryUserDatabase.java 
b/java/org/apache/catalina/users/MemoryUserDatabase.java
index 778a1a2..7c81f11 100644
--- a/java/org/apache/catalina/users/MemoryUserDatabase.java
+++ b/java/org/apache/catalina/users/MemoryUserDatabase.java
@@ -17,6 +17,7 @@
 package org.apache.catalina.users;
 
 import java.io.File;
+import java.io.FileNotFoundException;
 import java.io.FileOutputStream;
 import java.io.IOException;
 import java.io.OutputStreamWriter;
@@ -683,6 +684,11 @@ public class MemoryUserDatabase implements UserDatabase {
 try {
 // Can't close a uConn directly. Have to do it like this.
 uConn.getInputStream().close();
+} catch (FileNotFoundException fnfe) {
+// The file doesn't exist.
+// This has been logged above. No need to log again.
+// Set the last modified time to avoid repeated log 
messages
+this.lastModified = 0;
 } catch (IOException ioe) {
 log.warn(sm.getString("memoryUserDatabase.fileClose", 
pathname), ioe);
 }
diff --git a/webapps/docs/changelog.xml b/webapps/docs/changelog.xml
index 38c436d..98b2072 100644
--- a/webapps/docs/changelog.xml
+++ b/webapps/docs/changelog.xml
@@ -85,6 +85,11 @@
 support authentication persistence. Patch provided by Carsten Klein.
 (markt)
   
+  
+64184: Avoid repeated log messages if a
+MemoryUserDatabase is configured but the specified
+configuration file is missing. (markt)
+  
   
 64189: Expose the web application version String as a
 ServletContext attribute named


-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



[Bug 64184] Continuously trying to close the conf/tomcat-users.xml if it doesn't exist.

2020-03-03 Thread bugzilla
https://bz.apache.org/bugzilla/show_bug.cgi?id=64184

Mark Thomas  changed:

   What|Removed |Added

 Status|NEW |RESOLVED
 Resolution|--- |FIXED

--- Comment #4 from Mark Thomas  ---
Fixed in:
- master for 10.0.0-M2 onwards
- 9.0.x for 9.0.32 onwards
- 8.5.x for 8.5.52 onwards

-- 
You are receiving this mail because:
You are the assignee for the bug.
-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



buildbot success in on tomcat-85-trunk

2020-03-03 Thread buildbot
The Buildbot has detected a restored build on builder tomcat-85-trunk while 
building tomcat. Full details are available at:
https://ci.apache.org/builders/tomcat-85-trunk/builds/2195

Buildbot URL: https://ci.apache.org/

Buildslave for this Build: asf946_ubuntu

Build Reason: The AnyBranchScheduler scheduler named 'on-tomcat-85-commit' 
triggered this build
Build Source Stamp: [branch 8.5.x] a9a94e394a73b74e3937056e2dbba628f0211dc6
Blamelist: Mark Thomas 

Build succeeded!

Sincerely,
 -The Buildbot




-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



[Bug 64192] New: Bug in Tomcat HTTP2 POST - with big payload

2020-03-03 Thread bugzilla
https://bz.apache.org/bugzilla/show_bug.cgi?id=64192

Bug ID: 64192
   Summary: Bug in Tomcat HTTP2 POST - with big payload
   Product: Tomcat 9
   Version: 9.0.31
  Hardware: PC
Status: NEW
  Severity: normal
  Priority: P2
 Component: Catalina
  Assignee: dev@tomcat.apache.org
  Reporter: lz.zukow...@gmail.com
  Target Milestone: -

Created attachment 37056
  --> https://bz.apache.org/bugzilla/attachment.cgi?id=37056&action=edit
debug log and exception

I found a probably bug with http2 handling in tomcat.

When I sending HTTP2 POST request with big payload I see below exception.
This request is OK when I use Undertow for example or Tomcat with HTTP1.1

I prepared test where you can recreate this problem.
Here is link https://github.com/zulk666/demo-http2
To start the demo you have to run com.example.demo.DemoApplication first
then run test DemoApplicationTests.

Exception which I received is 
org.apache.coyote.http2.ConnectionException: Invalid frame type [HEADERS]


I tested also with curl, Chrome and Firefox and result is the same as in test.

-- 
You are receiving this mail because:
You are the assignee for the bug.
-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



[Bug 64191] Applications not working with 7.0.100

2020-03-03 Thread bugzilla
https://bz.apache.org/bugzilla/show_bug.cgi?id=64191

--- Comment #2 from thomas.w...@gfk.com ---
(In reply to Mark Thomas from comment #1)
> Probably the SCI regression that has already been fixed. Are you able to
> build Tomcat 7.0.x from source to test the latest code?

Unfortunately not (as we have rules for production enviornments to only use
final versions) - would this been included in the 7.0.101 then?

-- 
You are receiving this mail because:
You are the assignee for the bug.
-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



[Bug 64191] Applications not working with 7.0.100

2020-03-03 Thread bugzilla
https://bz.apache.org/bugzilla/show_bug.cgi?id=64191

--- Comment #3 from Mark Thomas  ---
How about a test environment? It would be helpful to know if the issue you are
seeing has already been fixed or is a new issue.

-- 
You are receiving this mail because:
You are the assignee for the bug.
-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



[Bug 64191] Applications not working with 7.0.100

2020-03-03 Thread bugzilla
https://bz.apache.org/bugzilla/show_bug.cgi?id=64191

--- Comment #4 from thomas.w...@gfk.com ---
(In reply to Mark Thomas from comment #3)
> How about a test environment? It would be helpful to know if the issue you
> are seeing has already been fixed or is a new issue.

Yes, you're right - can you give me hint, where to find it?

-- 
You are receiving this mail because:
You are the assignee for the bug.
-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



[Bug 64190] OneLineFormatter always add milliseconds at the end of timestamp

2020-03-03 Thread bugzilla
https://bz.apache.org/bugzilla/show_bug.cgi?id=64190

Christopher Schultz  changed:

   What|Removed |Added

 OS||All

--- Comment #1 from Christopher Schultz  ---
This might be difficult, due to the way the OneLineFormatter caches DateFormat
objects and only updates the "time" every 1000ms.

Whatever solution you come up with needs to maintain the existing performance
characteristics of the OneLineFormatter.

-- 
You are receiving this mail because:
You are the assignee for the bug.
-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



[Bug 64190] OneLineFormatter always add milliseconds at the end of timestamp

2020-03-03 Thread bugzilla
https://bz.apache.org/bugzilla/show_bug.cgi?id=64190

--- Comment #2 from Mark Thomas  ---
I have a patch ready that does this.

-- 
You are receiving this mail because:
You are the assignee for the bug.
-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



[Bug 64191] Applications not working with 7.0.100

2020-03-03 Thread bugzilla
https://bz.apache.org/bugzilla/show_bug.cgi?id=64191

--- Comment #5 from Mark Thomas  ---
I uploaded a build here:
http://people.apache.org/~markt/dev/v7.0.101-dev/

This isn't an official release. It is just for testing purposes.

-- 
You are receiving this mail because:
You are the assignee for the bug.
-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



[tomcat] branch master updated: Update removal notice

2020-03-03 Thread remm
This is an automated email from the ASF dual-hosted git repository.

remm pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/tomcat.git


The following commit(s) were added to refs/heads/master by this push:
 new 1ab5dec  Update removal notice
1ab5dec is described below

commit 1ab5decee4e77008e860bc7e701379f6a17ae7cd
Author: remm 
AuthorDate: Tue Mar 3 15:25:12 2020 +0100

Update removal notice

The refactoring to nanoTime will most likely not be backported to Tomcat
9, so move the notice version number forward.
---
 java/org/apache/coyote/Request.java | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/java/org/apache/coyote/Request.java 
b/java/org/apache/coyote/Request.java
index 05ba75c..dc77bf0 100644
--- a/java/org/apache/coyote/Request.java
+++ b/java/org/apache/coyote/Request.java
@@ -571,7 +571,7 @@ public final class Request {
 /**
  *
  * @param startTime time
- * @deprecated This setter will be removed in Tomcat 10.
+ * @deprecated This setter will be removed in Tomcat 10.1.
  */
 @Deprecated
 public void setStartTime(long startTime) {


-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



[tomcat] branch master updated: Note incompatible time unit change in the javadoc

2020-03-03 Thread remm
This is an automated email from the ASF dual-hosted git repository.

remm pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/tomcat.git


The following commit(s) were added to refs/heads/master by this push:
 new 0758356  Note incompatible time unit change in the javadoc
0758356 is described below

commit 075835663ff357fb57c54072b2577105601dc3e5
Author: remm 
AuthorDate: Tue Mar 3 15:30:49 2020 +0100

Note incompatible time unit change in the javadoc
---
 java/org/apache/catalina/AccessLog.java | 4 +++-
 1 file changed, 3 insertions(+), 1 deletion(-)

diff --git a/java/org/apache/catalina/AccessLog.java 
b/java/org/apache/catalina/AccessLog.java
index 6674309..bd10497 100644
--- a/java/org/apache/catalina/AccessLog.java
+++ b/java/org/apache/catalina/AccessLog.java
@@ -76,7 +76,9 @@ public interface AccessLog {
  * @param request   Request (associated with the response) to log
  * @param response  Response (associated with the request) to log
  * @param time  Time taken to process the request/response in
- *  nanoseconds (use 0 if not known)
+ *  nanoseconds (use 0 if not known); in Tomcat
+ *  versions prior to 10, the time unit was
+ *  milliseconds
  */
 public void log(Request request, Response response, long time);
 


-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



[tomcat] branch master updated: BZ 64190 Add 'proper' ms support to OneLineFormatter.

2020-03-03 Thread markt
This is an automated email from the ASF dual-hosted git repository.

markt pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/tomcat.git


The following commit(s) were added to refs/heads/master by this push:
 new 4ad0a71  BZ 64190 Add 'proper' ms support to OneLineFormatter.
4ad0a71 is described below

commit 4ad0a71bc11de50e0fe23fc38e6e67f134aa0589
Author: Mark Thomas 
AuthorDate: Tue Mar 3 14:36:08 2020 +

BZ 64190 Add 'proper' ms support to OneLineFormatter.

S SS or SSS can now be used (once) anywhere in the format String.
Format strings without S SS or SSS are now ~30% faster
The current default (effectively "dd-MMM- HH:mm:ss.SSS") is within
less than 1% of the old implementation.
Using S SS or SSS anywhere but the very end doubles the time taken to
generate the timestamp.
---
 java/org/apache/juli/OneLineFormatter.java | 77 +++---
 .../TestOneLineFormatterMillisPerformance.java | 70 
 webapps/docs/changelog.xml |  5 ++
 3 files changed, 142 insertions(+), 10 deletions(-)

diff --git a/java/org/apache/juli/OneLineFormatter.java 
b/java/org/apache/juli/OneLineFormatter.java
index 75845cf..fad37b0 100644
--- a/java/org/apache/juli/OneLineFormatter.java
+++ b/java/org/apache/juli/OneLineFormatter.java
@@ -51,7 +51,7 @@ public class OneLineFormatter extends Formatter {
 };
 
 /* Timestamp format */
-private static final String DEFAULT_TIME_FORMAT = "dd-MMM- HH:mm:ss";
+private static final String DEFAULT_TIME_FORMAT = "dd-MMM- 
HH:mm:ss.SSS";
 
 /**
  * The size of our global date format cache
@@ -68,6 +68,8 @@ public class OneLineFormatter extends Formatter {
  */
 private ThreadLocal localDateCache;
 
+private volatile MillisHandling millisHandling = MillisHandling.APPEND;
+
 
 public OneLineFormatter() {
 String timeFormat = LogManager.getLogManager().getProperty(
@@ -86,12 +88,31 @@ public class OneLineFormatter extends Formatter {
  *   {@link java.text.SimpleDateFormat} syntax
  */
 public void setTimeFormat(final String timeFormat) {
+final String cachedTimeFormat;
+
+if (timeFormat.endsWith(".SSS")) {
+cachedTimeFormat = timeFormat.substring(0,  timeFormat.length() - 
4);
+millisHandling = MillisHandling.APPEND;
+} else if (timeFormat.contains("SSS")) {
+millisHandling = MillisHandling.REPLACE_SSS;
+cachedTimeFormat = timeFormat;
+} else if (timeFormat.contains("SS")) {
+millisHandling = MillisHandling.REPLACE_SS;
+cachedTimeFormat = timeFormat;
+} else if (timeFormat.contains("S")) {
+millisHandling = MillisHandling.REPLACE_S;
+cachedTimeFormat = timeFormat;
+} else {
+millisHandling = MillisHandling.NONE;
+cachedTimeFormat = timeFormat;
+}
+
 final DateFormatCache globalDateCache =
-new DateFormatCache(globalCacheSize, timeFormat, null);
+new DateFormatCache(globalCacheSize, cachedTimeFormat, null);
 localDateCache = new ThreadLocal() {
 @Override
 protected DateFormatCache initialValue() {
-return new DateFormatCache(localCacheSize, timeFormat, 
globalDateCache);
+return new DateFormatCache(localCacheSize, cachedTimeFormat, 
globalDateCache);
 }
 };
 }
@@ -156,18 +177,45 @@ public class OneLineFormatter extends Formatter {
 }
 
 protected void addTimestamp(StringBuilder buf, long timestamp) {
-buf.append(localDateCache.get().getFormat(timestamp));
-long frac = timestamp % 1000;
-buf.append('.');
-if (frac < 100) {
-if (frac < 10) {
+String cachedTimeStamp = localDateCache.get().getFormat(timestamp);
+if (millisHandling == MillisHandling.NONE) {
+buf.append(cachedTimeStamp);
+} else if (millisHandling == MillisHandling.APPEND) {
+buf.append(cachedTimeStamp);
+long frac = timestamp % 1000;
+buf.append('.');
+if (frac < 100) {
+if (frac < 10) {
+buf.append('0');
+buf.append('0');
+} else {
+buf.append('0');
+}
+}
+buf.append(frac);
+} else {
+// Some version of replace
+long frac = timestamp % 1000;
+// Formatted string may vary in length so the insert point may vary
+int insertStart = cachedTimeStamp.indexOf('#');
+buf.append(cachedTimeStamp.subSequence(0, insertStart));
+if (frac < 100 && millisHandling == MillisHandling.REPLACE_SSS) {
 buf.append('0');
+if (frac < 10) {
+buf.

[tomcat] branch 9.0.x updated: BZ 64190 Add 'proper' ms support to OneLineFormatter.

2020-03-03 Thread markt
This is an automated email from the ASF dual-hosted git repository.

markt pushed a commit to branch 9.0.x
in repository https://gitbox.apache.org/repos/asf/tomcat.git


The following commit(s) were added to refs/heads/9.0.x by this push:
 new 0625a7d  BZ 64190 Add 'proper' ms support to OneLineFormatter.
0625a7d is described below

commit 0625a7dc0b239292ae435f36e4ba2e8297a7fa7f
Author: Mark Thomas 
AuthorDate: Tue Mar 3 14:36:08 2020 +

BZ 64190 Add 'proper' ms support to OneLineFormatter.

S SS or SSS can now be used (once) anywhere in the format String.
Format strings without S SS or SSS are now ~30% faster
The current default (effectively "dd-MMM- HH:mm:ss.SSS") is within
less than 1% of the old implementation.
Using S SS or SSS anywhere but the very end doubles the time taken to
generate the timestamp.
---
 java/org/apache/juli/OneLineFormatter.java | 77 +++---
 .../TestOneLineFormatterMillisPerformance.java | 70 
 webapps/docs/changelog.xml |  5 ++
 3 files changed, 142 insertions(+), 10 deletions(-)

diff --git a/java/org/apache/juli/OneLineFormatter.java 
b/java/org/apache/juli/OneLineFormatter.java
index 75845cf..fad37b0 100644
--- a/java/org/apache/juli/OneLineFormatter.java
+++ b/java/org/apache/juli/OneLineFormatter.java
@@ -51,7 +51,7 @@ public class OneLineFormatter extends Formatter {
 };
 
 /* Timestamp format */
-private static final String DEFAULT_TIME_FORMAT = "dd-MMM- HH:mm:ss";
+private static final String DEFAULT_TIME_FORMAT = "dd-MMM- 
HH:mm:ss.SSS";
 
 /**
  * The size of our global date format cache
@@ -68,6 +68,8 @@ public class OneLineFormatter extends Formatter {
  */
 private ThreadLocal localDateCache;
 
+private volatile MillisHandling millisHandling = MillisHandling.APPEND;
+
 
 public OneLineFormatter() {
 String timeFormat = LogManager.getLogManager().getProperty(
@@ -86,12 +88,31 @@ public class OneLineFormatter extends Formatter {
  *   {@link java.text.SimpleDateFormat} syntax
  */
 public void setTimeFormat(final String timeFormat) {
+final String cachedTimeFormat;
+
+if (timeFormat.endsWith(".SSS")) {
+cachedTimeFormat = timeFormat.substring(0,  timeFormat.length() - 
4);
+millisHandling = MillisHandling.APPEND;
+} else if (timeFormat.contains("SSS")) {
+millisHandling = MillisHandling.REPLACE_SSS;
+cachedTimeFormat = timeFormat;
+} else if (timeFormat.contains("SS")) {
+millisHandling = MillisHandling.REPLACE_SS;
+cachedTimeFormat = timeFormat;
+} else if (timeFormat.contains("S")) {
+millisHandling = MillisHandling.REPLACE_S;
+cachedTimeFormat = timeFormat;
+} else {
+millisHandling = MillisHandling.NONE;
+cachedTimeFormat = timeFormat;
+}
+
 final DateFormatCache globalDateCache =
-new DateFormatCache(globalCacheSize, timeFormat, null);
+new DateFormatCache(globalCacheSize, cachedTimeFormat, null);
 localDateCache = new ThreadLocal() {
 @Override
 protected DateFormatCache initialValue() {
-return new DateFormatCache(localCacheSize, timeFormat, 
globalDateCache);
+return new DateFormatCache(localCacheSize, cachedTimeFormat, 
globalDateCache);
 }
 };
 }
@@ -156,18 +177,45 @@ public class OneLineFormatter extends Formatter {
 }
 
 protected void addTimestamp(StringBuilder buf, long timestamp) {
-buf.append(localDateCache.get().getFormat(timestamp));
-long frac = timestamp % 1000;
-buf.append('.');
-if (frac < 100) {
-if (frac < 10) {
+String cachedTimeStamp = localDateCache.get().getFormat(timestamp);
+if (millisHandling == MillisHandling.NONE) {
+buf.append(cachedTimeStamp);
+} else if (millisHandling == MillisHandling.APPEND) {
+buf.append(cachedTimeStamp);
+long frac = timestamp % 1000;
+buf.append('.');
+if (frac < 100) {
+if (frac < 10) {
+buf.append('0');
+buf.append('0');
+} else {
+buf.append('0');
+}
+}
+buf.append(frac);
+} else {
+// Some version of replace
+long frac = timestamp % 1000;
+// Formatted string may vary in length so the insert point may vary
+int insertStart = cachedTimeStamp.indexOf('#');
+buf.append(cachedTimeStamp.subSequence(0, insertStart));
+if (frac < 100 && millisHandling == MillisHandling.REPLACE_SSS) {
 buf.append('0');
+if (frac < 10) {
+buf.ap

[tomcat] branch 7.0.x updated: BZ 64190 Add 'proper' ms support to OneLineFormatter.

2020-03-03 Thread markt
This is an automated email from the ASF dual-hosted git repository.

markt pushed a commit to branch 7.0.x
in repository https://gitbox.apache.org/repos/asf/tomcat.git


The following commit(s) were added to refs/heads/7.0.x by this push:
 new 20cd6b7  BZ 64190 Add 'proper' ms support to OneLineFormatter.
20cd6b7 is described below

commit 20cd6b7712c738a45ef841eb8b6bb975ed11b8c2
Author: Mark Thomas 
AuthorDate: Tue Mar 3 14:36:08 2020 +

BZ 64190 Add 'proper' ms support to OneLineFormatter.

S SS or SSS can now be used (once) anywhere in the format String.
Format strings without S SS or SSS are now ~30% faster
The current default (effectively "dd-MMM- HH:mm:ss.SSS") is within
less than 1% of the old implementation.
Using S SS or SSS anywhere but the very end doubles the time taken to
generate the timestamp.
---
 java/org/apache/juli/OneLineFormatter.java | 77 +++---
 .../TestOneLineFormatterMillisPerformance.java | 70 
 webapps/docs/changelog.xml |  5 ++
 3 files changed, 142 insertions(+), 10 deletions(-)

diff --git a/java/org/apache/juli/OneLineFormatter.java 
b/java/org/apache/juli/OneLineFormatter.java
index ee97d11..3daf126 100644
--- a/java/org/apache/juli/OneLineFormatter.java
+++ b/java/org/apache/juli/OneLineFormatter.java
@@ -52,7 +52,7 @@ public class OneLineFormatter extends Formatter {
 };
 
 /* Timestamp format */
-private static final String DEFAULT_TIME_FORMAT = "dd-MMM- HH:mm:ss";
+private static final String DEFAULT_TIME_FORMAT = "dd-MMM- 
HH:mm:ss.SSS";
 
 /**
  * The size of our global date format cache
@@ -69,6 +69,8 @@ public class OneLineFormatter extends Formatter {
  */
 private ThreadLocal localDateCache;
 
+private volatile MillisHandling millisHandling = MillisHandling.APPEND;
+
 
 public OneLineFormatter() {
 String timeFormat = LogManager.getLogManager().getProperty(
@@ -87,12 +89,31 @@ public class OneLineFormatter extends Formatter {
  *   {@link java.text.SimpleDateFormat} syntax
  */
 public void setTimeFormat(final String timeFormat) {
+final String cachedTimeFormat;
+
+if (timeFormat.endsWith(".SSS")) {
+cachedTimeFormat = timeFormat.substring(0,  timeFormat.length() - 
4);
+millisHandling = MillisHandling.APPEND;
+} else if (timeFormat.contains("SSS")) {
+millisHandling = MillisHandling.REPLACE_SSS;
+cachedTimeFormat = timeFormat;
+} else if (timeFormat.contains("SS")) {
+millisHandling = MillisHandling.REPLACE_SS;
+cachedTimeFormat = timeFormat;
+} else if (timeFormat.contains("S")) {
+millisHandling = MillisHandling.REPLACE_S;
+cachedTimeFormat = timeFormat;
+} else {
+millisHandling = MillisHandling.NONE;
+cachedTimeFormat = timeFormat;
+}
+
 final DateFormatCache globalDateCache =
-new DateFormatCache(globalCacheSize, timeFormat, null);
+new DateFormatCache(globalCacheSize, cachedTimeFormat, null);
 localDateCache = new ThreadLocal() {
 @Override
 protected DateFormatCache initialValue() {
-return new DateFormatCache(localCacheSize, timeFormat, 
globalDateCache);
+return new DateFormatCache(localCacheSize, cachedTimeFormat, 
globalDateCache);
 }
 };
 }
@@ -157,18 +178,45 @@ public class OneLineFormatter extends Formatter {
 }
 
 protected void addTimestamp(StringBuilder buf, long timestamp) {
-buf.append(localDateCache.get().getFormat(timestamp));
-long frac = timestamp % 1000;
-buf.append('.');
-if (frac < 100) {
-if (frac < 10) {
+String cachedTimeStamp = localDateCache.get().getFormat(timestamp);
+if (millisHandling == MillisHandling.NONE) {
+buf.append(cachedTimeStamp);
+} else if (millisHandling == MillisHandling.APPEND) {
+buf.append(cachedTimeStamp);
+long frac = timestamp % 1000;
+buf.append('.');
+if (frac < 100) {
+if (frac < 10) {
+buf.append('0');
+buf.append('0');
+} else {
+buf.append('0');
+}
+}
+buf.append(frac);
+} else {
+// Some version of replace
+long frac = timestamp % 1000;
+// Formatted string may vary in length so the insert point may vary
+int insertStart = cachedTimeStamp.indexOf('#');
+buf.append(cachedTimeStamp.subSequence(0, insertStart));
+if (frac < 100 && millisHandling == MillisHandling.REPLACE_SSS) {
 buf.append('0');
+if (frac < 10) {
+buf.ap

[tomcat] branch 8.5.x updated: BZ 64190 Add 'proper' ms support to OneLineFormatter.

2020-03-03 Thread markt
This is an automated email from the ASF dual-hosted git repository.

markt pushed a commit to branch 8.5.x
in repository https://gitbox.apache.org/repos/asf/tomcat.git


The following commit(s) were added to refs/heads/8.5.x by this push:
 new e931ab0  BZ 64190 Add 'proper' ms support to OneLineFormatter.
e931ab0 is described below

commit e931ab087ef4317b6fc568397aa25126964f5632
Author: Mark Thomas 
AuthorDate: Tue Mar 3 14:36:08 2020 +

BZ 64190 Add 'proper' ms support to OneLineFormatter.

S SS or SSS can now be used (once) anywhere in the format String.
Format strings without S SS or SSS are now ~30% faster
The current default (effectively "dd-MMM- HH:mm:ss.SSS") is within
less than 1% of the old implementation.
Using S SS or SSS anywhere but the very end doubles the time taken to
generate the timestamp.
---
 java/org/apache/juli/OneLineFormatter.java | 77 +++---
 .../TestOneLineFormatterMillisPerformance.java | 70 
 webapps/docs/changelog.xml |  5 ++
 3 files changed, 142 insertions(+), 10 deletions(-)

diff --git a/java/org/apache/juli/OneLineFormatter.java 
b/java/org/apache/juli/OneLineFormatter.java
index 75845cf..fad37b0 100644
--- a/java/org/apache/juli/OneLineFormatter.java
+++ b/java/org/apache/juli/OneLineFormatter.java
@@ -51,7 +51,7 @@ public class OneLineFormatter extends Formatter {
 };
 
 /* Timestamp format */
-private static final String DEFAULT_TIME_FORMAT = "dd-MMM- HH:mm:ss";
+private static final String DEFAULT_TIME_FORMAT = "dd-MMM- 
HH:mm:ss.SSS";
 
 /**
  * The size of our global date format cache
@@ -68,6 +68,8 @@ public class OneLineFormatter extends Formatter {
  */
 private ThreadLocal localDateCache;
 
+private volatile MillisHandling millisHandling = MillisHandling.APPEND;
+
 
 public OneLineFormatter() {
 String timeFormat = LogManager.getLogManager().getProperty(
@@ -86,12 +88,31 @@ public class OneLineFormatter extends Formatter {
  *   {@link java.text.SimpleDateFormat} syntax
  */
 public void setTimeFormat(final String timeFormat) {
+final String cachedTimeFormat;
+
+if (timeFormat.endsWith(".SSS")) {
+cachedTimeFormat = timeFormat.substring(0,  timeFormat.length() - 
4);
+millisHandling = MillisHandling.APPEND;
+} else if (timeFormat.contains("SSS")) {
+millisHandling = MillisHandling.REPLACE_SSS;
+cachedTimeFormat = timeFormat;
+} else if (timeFormat.contains("SS")) {
+millisHandling = MillisHandling.REPLACE_SS;
+cachedTimeFormat = timeFormat;
+} else if (timeFormat.contains("S")) {
+millisHandling = MillisHandling.REPLACE_S;
+cachedTimeFormat = timeFormat;
+} else {
+millisHandling = MillisHandling.NONE;
+cachedTimeFormat = timeFormat;
+}
+
 final DateFormatCache globalDateCache =
-new DateFormatCache(globalCacheSize, timeFormat, null);
+new DateFormatCache(globalCacheSize, cachedTimeFormat, null);
 localDateCache = new ThreadLocal() {
 @Override
 protected DateFormatCache initialValue() {
-return new DateFormatCache(localCacheSize, timeFormat, 
globalDateCache);
+return new DateFormatCache(localCacheSize, cachedTimeFormat, 
globalDateCache);
 }
 };
 }
@@ -156,18 +177,45 @@ public class OneLineFormatter extends Formatter {
 }
 
 protected void addTimestamp(StringBuilder buf, long timestamp) {
-buf.append(localDateCache.get().getFormat(timestamp));
-long frac = timestamp % 1000;
-buf.append('.');
-if (frac < 100) {
-if (frac < 10) {
+String cachedTimeStamp = localDateCache.get().getFormat(timestamp);
+if (millisHandling == MillisHandling.NONE) {
+buf.append(cachedTimeStamp);
+} else if (millisHandling == MillisHandling.APPEND) {
+buf.append(cachedTimeStamp);
+long frac = timestamp % 1000;
+buf.append('.');
+if (frac < 100) {
+if (frac < 10) {
+buf.append('0');
+buf.append('0');
+} else {
+buf.append('0');
+}
+}
+buf.append(frac);
+} else {
+// Some version of replace
+long frac = timestamp % 1000;
+// Formatted string may vary in length so the insert point may vary
+int insertStart = cachedTimeStamp.indexOf('#');
+buf.append(cachedTimeStamp.subSequence(0, insertStart));
+if (frac < 100 && millisHandling == MillisHandling.REPLACE_SSS) {
 buf.append('0');
+if (frac < 10) {
+buf.ap

[Bug 64190] OneLineFormatter always add milliseconds at the end of timestamp

2020-03-03 Thread bugzilla
https://bz.apache.org/bugzilla/show_bug.cgi?id=64190

Mark Thomas  changed:

   What|Removed |Added

 Resolution|--- |FIXED
 Status|NEW |RESOLVED

--- Comment #3 from Mark Thomas  ---
Fixed in:
- master for 10.0.0-M2 onwards
- 9.0.x for 9.0.32 onwards
- 8.5.x for 8.5.52 onwards
- 7.0.x for 7.0.101 onwards

-- 
You are receiving this mail because:
You are the assignee for the bug.
-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



buildbot failure in on tomcat-7-trunk

2020-03-03 Thread buildbot
The Buildbot has detected a new failure on builder tomcat-7-trunk while 
building tomcat. Full details are available at:
https://ci.apache.org/builders/tomcat-7-trunk/builds/1622

Buildbot URL: https://ci.apache.org/

Buildslave for this Build: asf946_ubuntu

Build Reason: The AnyBranchScheduler scheduler named 'on-tomcat-7-commit' 
triggered this build
Build Source Stamp: [branch 7.0.x] 20cd6b7712c738a45ef841eb8b6bb975ed11b8c2
Blamelist: Mark Thomas 

BUILD FAILED: failed compile_1

Sincerely,
 -The Buildbot




-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



[tomcat] branch 7.0.x updated: Fix back-port

2020-03-03 Thread markt
This is an automated email from the ASF dual-hosted git repository.

markt pushed a commit to branch 7.0.x
in repository https://gitbox.apache.org/repos/asf/tomcat.git


The following commit(s) were added to refs/heads/7.0.x by this push:
 new 5cfdedd  Fix back-port
5cfdedd is described below

commit 5cfdedde90aa1a953bdcfaf589126fbd4c58f20a
Author: Mark Thomas 
AuthorDate: Tue Mar 3 17:35:15 2020 +

Fix back-port
---
 test/org/apache/juli/TestOneLineFormatterMillisPerformance.java | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/test/org/apache/juli/TestOneLineFormatterMillisPerformance.java 
b/test/org/apache/juli/TestOneLineFormatterMillisPerformance.java
index b7c0cab..7f0758d 100644
--- a/test/org/apache/juli/TestOneLineFormatterMillisPerformance.java
+++ b/test/org/apache/juli/TestOneLineFormatterMillisPerformance.java
@@ -31,7 +31,7 @@ public class TestOneLineFormatterMillisPerformance {
 @Parameterized.Parameters(name = "{index}: format[{0}]")
 public static Collection parameters() {
 
-List parameterSets = new ArrayList<>();
+List parameterSets = new ArrayList();
 
 parameterSets.add(new String[] { "dd-MMM- HH:mm:ss.SSS" });
 parameterSets.add(new String[] { "dd-MMM- HH:mm:ss.SS" });


-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



[Bug 64192] Bug in Tomcat HTTP2 POST - with big payload

2020-03-03 Thread bugzilla
https://bz.apache.org/bugzilla/show_bug.cgi?id=64192

Mark Thomas  changed:

   What|Removed |Added

 OS||All

--- Comment #1 from Mark Thomas  ---
If you set useAsyncIO="false" on the Connector this should start working.

We need to look into where things are going wrong in the asynIO code. I've
narrowed it down to reading one less byte than is actually present. This
triggers an off-by-one error when reading the next frame which causes it to be
read as a HEADERS frame rather than a SETIINGS frame.

-- 
You are receiving this mail because:
You are the assignee for the bug.
-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



[Bug 64089] Resource paths resolve symlinks

2020-03-03 Thread bugzilla
https://bz.apache.org/bugzilla/show_bug.cgi?id=64089

--- Comment #12 from Mark Thomas  ---
I'll take a look. Meanwhile, can you provide the full stack trace please.

-- 
You are receiving this mail because:
You are the assignee for the bug.
-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



[Bug 64089] Resource paths resolve symlinks

2020-03-03 Thread bugzilla
https://bz.apache.org/bugzilla/show_bug.cgi?id=64089

--- Comment #13 from Marvin Fröhlich  ---
Sure. This one is for the variant with only
"${catalina.base}/foo/bar/myentity.xml"

java.net.MalformedURLException: no protocol:
${catalina.base}/foo/bar/myentity.xml
at java.base/java.net.URL.(URL.java:634)
at java.base/java.net.URL.(URL.java:530)
at java.base/java.net.URL.(URL.java:477)
at
java.xml/com.sun.org.apache.xerces.internal.impl.XMLEntityManager.setupCurrentEntity(XMLEntityManager.java:651)
at
java.xml/com.sun.org.apache.xerces.internal.impl.XMLEntityManager.startEntity(XMLEntityManager.java:1401)
at
java.xml/com.sun.org.apache.xerces.internal.impl.XMLEntityManager.startEntity(XMLEntityManager.java:1337)
at
java.xml/com.sun.org.apache.xerces.internal.impl.XMLDocumentFragmentScannerImpl.scanEntityReference(XMLDocumentFragmentScannerImpl.java:1844)
at
java.xml/com.sun.org.apache.xerces.internal.impl.XMLDocumentFragmentScannerImpl$FragmentContentDriver.next(XMLDocumentFragmentScannerImpl.java:2985)
at
java.xml/com.sun.org.apache.xerces.internal.impl.XMLDocumentScannerImpl.next(XMLDocumentScannerImpl.java:605)
at
java.xml/com.sun.org.apache.xerces.internal.impl.XMLDocumentFragmentScannerImpl.scanDocument(XMLDocumentFragmentScannerImpl.java:534)
at
java.xml/com.sun.org.apache.xerces.internal.parsers.XML11Configuration.parse(XML11Configuration.java:888)
at
java.xml/com.sun.org.apache.xerces.internal.parsers.XML11Configuration.parse(XML11Configuration.java:824)
at
java.xml/com.sun.org.apache.xerces.internal.parsers.XMLParser.parse(XMLParser.java:141)
at
java.xml/com.sun.org.apache.xerces.internal.parsers.DOMParser.parse(DOMParser.java:246)
at
java.xml/com.sun.org.apache.xerces.internal.jaxp.DocumentBuilderImpl.parse(DocumentBuilderImpl.java:339)
at
java.xml/javax.xml.parsers.DocumentBuilder.parse(DocumentBuilder.java:206)
at
com.infolog.commons.xml.w3c.XMLHelper.loadDocument(XMLHelper.java:464)
at
com.infolog.commons.xml.w3c.XMLHelper.loadDocument(XMLHelper.java:485)
at
com.infolog.webdoc.server.TomcatEnvironment.readWebXML(TomcatEnvironment.java:232)
at
com.infolog.webdoc.server.TomcatEnvironment.getMaxUploadSize(TomcatEnvironment.java:259)
at
com.infolog.webdoc.database.DatabaseParameters.checkValidity(DatabaseParameters.java:127)
at
com.infolog.webdoc.server.WebDocServletValidation.sanityCheckDatabaseConnection(WebDocServletValidation.java:94)
at
com.infolog.webdoc.server.WebDocServletValidation.sanityCheckEnvironment(WebDocServletValidation.java:198)
at com.infolog.webdoc.server.WebDocServlet.init(WebDocServlet.java:388)
at javax.servlet.GenericServlet.init(GenericServlet.java:158)
at
org.apache.catalina.core.StandardWrapper.initServlet(StandardWrapper.java:1134)
at
org.apache.catalina.core.StandardWrapper.loadServlet(StandardWrapper.java:1089)
at
org.apache.catalina.core.StandardWrapper.load(StandardWrapper.java:983)
at
org.apache.catalina.core.StandardContext.loadOnStartup(StandardContext.java:4871)
at
org.apache.catalina.core.StandardContext.startInternal(StandardContext.java:5180)
at org.apache.catalina.util.LifecycleBase.start(LifecycleBase.java:183)
at
org.apache.catalina.core.ContainerBase.addChildInternal(ContainerBase.java:717)
at
org.apache.catalina.core.ContainerBase.addChild(ContainerBase.java:690)
at
org.apache.catalina.core.StandardHost.addChild(StandardHost.java:705)
at
org.apache.catalina.startup.HostConfig.deployDirectory(HostConfig.java:1133)
at
org.apache.catalina.startup.HostConfig$DeployDirectory.run(HostConfig.java:1867)
at
java.base/java.util.concurrent.Executors$RunnableAdapter.call(Executors.java:515)
at java.base/java.util.concurrent.FutureTask.run(FutureTask.java:264)
at
org.apache.tomcat.util.threads.InlineExecutorService.execute(InlineExecutorService.java:75)
at
java.base/java.util.concurrent.AbstractExecutorService.submit(AbstractExecutorService.java:118)
at
org.apache.catalina.startup.HostConfig.deployDirectories(HostConfig.java:1045)
at
org.apache.catalina.startup.HostConfig.deployApps(HostConfig.java:429)
at org.apache.catalina.startup.HostConfig.start(HostConfig.java:1576)
at
org.apache.catalina.startup.HostConfig.lifecycleEvent(HostConfig.java:309)
at
org.apache.catalina.util.LifecycleBase.fireLifecycleEvent(LifecycleBase.java:123)
at
org.apache.catalina.util.LifecycleBase.setStateInternal(LifecycleBase.java:423)
at
org.apache.catalina.util.LifecycleBase.setState(LifecycleBase.java:366)
at
org.apache.catalina.core.ContainerBase.startInternal(ContainerBase.java:936)
at
org.apache.catalina.core.StandardHost.startInternal(StandardHost.java:841)
at org.apache.catalina.util.Lifecyc

[Bug 64089] Resource paths resolve symlinks

2020-03-03 Thread bugzilla
https://bz.apache.org/bugzilla/show_bug.cgi?id=64089

Marvin Fröhlich  changed:

   What|Removed |Added

 Status|REOPENED|RESOLVED
 Resolution|--- |FIXED

--- Comment #14 from Marvin Fröhlich  ---
Oh, please forget that. This code comes from my own XML parsing. I'm very
sorry!

-- 
You are receiving this mail because:
You are the assignee for the bug.
-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



[Bug 64089] Resource paths resolve symlinks

2020-03-03 Thread bugzilla
https://bz.apache.org/bugzilla/show_bug.cgi?id=64089

--- Comment #15 from Marvin Fröhlich  ---
If you can, please delete today's comments here (except for the first one) to
avoid confusion for others.

-- 
You are receiving this mail because:
You are the assignee for the bug.
-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



buildbot failure in on tomcat-85-trunk

2020-03-03 Thread buildbot
The Buildbot has detected a new failure on builder tomcat-85-trunk while 
building tomcat. Full details are available at:
https://ci.apache.org/builders/tomcat-85-trunk/builds/2194

Buildbot URL: https://ci.apache.org/

Buildslave for this Build: asf946_ubuntu

Build Reason: The AnyBranchScheduler scheduler named 'on-tomcat-85-commit' 
triggered this build
Build Source Stamp: [branch 8.5.x] 644d59a717b3a5017d07a6d67eab364e3fc89527
Blamelist: Alexander Scheel 

BUILD FAILED: failed compile_1

Sincerely,
 -The Buildbot




-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



[tomcat] branch master updated: Increase margin to avoid false positives

2020-03-03 Thread markt
This is an automated email from the ASF dual-hosted git repository.

markt pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/tomcat.git


The following commit(s) were added to refs/heads/master by this push:
 new a185000  Increase margin to avoid false positives
a185000 is described below

commit a1850007cb007b891268075f6c5c65fea74f2d87
Author: Mark Thomas 
AuthorDate: Tue Mar 3 10:08:39 2020 +

Increase margin to avoid false positives
---
 test/org/apache/coyote/http2/TestHttp2Section_5_3.java | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/test/org/apache/coyote/http2/TestHttp2Section_5_3.java 
b/test/org/apache/coyote/http2/TestHttp2Section_5_3.java
index 18eaf4f..d85c620 100644
--- a/test/org/apache/coyote/http2/TestHttp2Section_5_3.java
+++ b/test/org/apache/coyote/http2/TestHttp2Section_5_3.java
@@ -168,9 +168,9 @@ public class TestHttp2Section_5_3 extends Http2TestBase {
 Assert.fail("Unexpected stream: [" + output.getTrace() + "]");
 }
 // A value of more than 1 here is unlikely but possible depending 
on
-// how threads are scheduled. This has been observed as high as 12
-// on ci.apache.org so allow a margin and use 20.
-if (data[1] > 20) {
+// how threads are scheduled. This has been observed as high as 21
+// on ci.apache.org so allow a margin and use 30.
+if (data[1] > 30) {
 // Larger than expected body size
 Assert.fail("Larger than expected body: [" + output.getTrace() 
+ "] " + data[1]);
 }


-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



[tomcat] branch 9.0.x updated: Increase margin to avoid false positives

2020-03-03 Thread markt
This is an automated email from the ASF dual-hosted git repository.

markt pushed a commit to branch 9.0.x
in repository https://gitbox.apache.org/repos/asf/tomcat.git


The following commit(s) were added to refs/heads/9.0.x by this push:
 new 51f6bac  Increase margin to avoid false positives
51f6bac is described below

commit 51f6bac289b44427032b3c7613069780c702fe1e
Author: Mark Thomas 
AuthorDate: Tue Mar 3 10:08:39 2020 +

Increase margin to avoid false positives
---
 test/org/apache/coyote/http2/TestHttp2Section_5_3.java | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/test/org/apache/coyote/http2/TestHttp2Section_5_3.java 
b/test/org/apache/coyote/http2/TestHttp2Section_5_3.java
index 18eaf4f..d85c620 100644
--- a/test/org/apache/coyote/http2/TestHttp2Section_5_3.java
+++ b/test/org/apache/coyote/http2/TestHttp2Section_5_3.java
@@ -168,9 +168,9 @@ public class TestHttp2Section_5_3 extends Http2TestBase {
 Assert.fail("Unexpected stream: [" + output.getTrace() + "]");
 }
 // A value of more than 1 here is unlikely but possible depending 
on
-// how threads are scheduled. This has been observed as high as 12
-// on ci.apache.org so allow a margin and use 20.
-if (data[1] > 20) {
+// how threads are scheduled. This has been observed as high as 21
+// on ci.apache.org so allow a margin and use 30.
+if (data[1] > 30) {
 // Larger than expected body size
 Assert.fail("Larger than expected body: [" + output.getTrace() 
+ "] " + data[1]);
 }


-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



[tomcat] branch 8.5.x updated: Increase margin to avoid false positives

2020-03-03 Thread markt
This is an automated email from the ASF dual-hosted git repository.

markt pushed a commit to branch 8.5.x
in repository https://gitbox.apache.org/repos/asf/tomcat.git


The following commit(s) were added to refs/heads/8.5.x by this push:
 new a479a5b  Increase margin to avoid false positives
a479a5b is described below

commit a479a5b963e799eaee249e1300264d11274c69b9
Author: Mark Thomas 
AuthorDate: Tue Mar 3 10:08:39 2020 +

Increase margin to avoid false positives
---
 test/org/apache/coyote/http2/TestHttp2Section_5_3.java | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/test/org/apache/coyote/http2/TestHttp2Section_5_3.java 
b/test/org/apache/coyote/http2/TestHttp2Section_5_3.java
index a89a762..6c76cb4 100644
--- a/test/org/apache/coyote/http2/TestHttp2Section_5_3.java
+++ b/test/org/apache/coyote/http2/TestHttp2Section_5_3.java
@@ -168,9 +168,9 @@ public class TestHttp2Section_5_3 extends Http2TestBase {
 Assert.fail("Unexpected stream: [" + output.getTrace() + "]");
 }
 // A value of more than 1 here is unlikely but possible depending 
on
-// how threads are scheduled. This has been observed as high as 12
-// on ci.apache.org so allow a margin and use 20.
-if (data[1] > 20) {
+// how threads are scheduled. This has been observed as high as 21
+// on ci.apache.org so allow a margin and use 30.
+if (data[1] > 30) {
 // Larger than expected body size
 Assert.fail("Larger than expected body: [" + output.getTrace() 
+ "]");
 }


-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



[tomcat] branch master updated: BZ 61484. Repeated log messages with missing tomcat-users.xml

2020-03-03 Thread markt
This is an automated email from the ASF dual-hosted git repository.

markt pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/tomcat.git


The following commit(s) were added to refs/heads/master by this push:
 new b1e47ba  BZ 61484. Repeated log messages with missing tomcat-users.xml
b1e47ba is described below

commit b1e47bac680efa52ef88fd87f4cbf774adabae7b
Author: Mark Thomas 
AuthorDate: Tue Mar 3 10:29:19 2020 +

BZ 61484. Repeated log messages with missing tomcat-users.xml

https://bz.apache.org/bugzilla/show_bug.cgi?id=64184
---
 java/org/apache/catalina/users/MemoryUserDatabase.java | 6 ++
 webapps/docs/changelog.xml | 5 +
 2 files changed, 11 insertions(+)

-- 
You are receiving this mail because:
You are the assignee for the bug.
-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



buildbot success in on tomcat-7-trunk

2020-03-03 Thread buildbot
The Buildbot has detected a restored build on builder tomcat-7-trunk while 
building tomcat. Full details are available at:
https://ci.apache.org/builders/tomcat-7-trunk/builds/1623

Buildbot URL: https://ci.apache.org/

Buildslave for this Build: asf946_ubuntu

Build Reason: The AnyBranchScheduler scheduler named 'on-tomcat-7-commit' 
triggered this build
Build Source Stamp: [branch 7.0.x] 5cfdedde90aa1a953bdcfaf589126fbd4c58f20a
Blamelist: Mark Thomas 

Build succeeded!

Sincerely,
 -The Buildbot




-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



[GitHub] [tomcat] mschieder opened a new pull request #251: fixed misspelling

2020-03-03 Thread GitBox
mschieder opened a new pull request #251: fixed misspelling
URL: https://github.com/apache/tomcat/pull/251
 
 
   fixed misspelling: Autoriesierung > Autorisierung


This is an automated message from the Apache Git Service.
To respond to the message, please log on to GitHub and use the
URL above to go to the specific comment.
 
For queries about this service, please contact Infrastructure at:
us...@infra.apache.org


With regards,
Apache Git Services

-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



[Bug 64192] Bug in Tomcat HTTP2 POST - with big payload

2020-03-03 Thread bugzilla
https://bz.apache.org/bugzilla/show_bug.cgi?id=64192

--- Comment #2 from Remy Maucherat  ---
I didn't expect a real problem so I hadn't really investigated, so thanks for
finding that out.

That odd 16383 payload size in the logs is hard to miss. That's where that off
by one would occur, but I haven't found out why.

-- 
You are receiving this mail because:
You are the assignee for the bug.
-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



Trouble building and running Tomcat 10 unit tests

2020-03-03 Thread Christopher Schultz
-BEGIN PGP SIGNED MESSAGE-
Hash: SHA256

All,

I'm up-to-date with git master, using ant 1.9.13, JDK 13.

$ ant test

[...]

test-compile:
[javac] Compiling 1 source file to
/Users/christopherschultz/git/tomcat-trunk/output/testclasses
[javac] Ignoring source, target and bootclasspath as release has
been set
[javac]
/Users/christopherschultz/git/tomcat-trunk/test/org/apache/catalina/ant/
TestDeployTask.java:37:
error: cannot access BuildException
[javac] public void execute(String command,
InputStream istream, String contentType, long contentLength)
[javac] ^
[javac]   class file for BuildException not found
[javac] 1 error

Ant has this class. Not sure why it can't access it. Okay, fine, I'll
just delete the file and move on:

$ rm test/org/apache/catalina/ant/TestDeployTask.java
$ ant test

[...]

add-osgi:
 [echo] add-osgi
/Users/christopherschultz/git/tomcat-trunk/output/build/lib/catalina.jar
true
  [bndwrap] 1 ERRORS
  [bndwrap]  The default package '.' is not permitted by the
Import-Package syntax.
  [bndwrap]  This can be caused by compile errors in Eclipse because
Eclipse creates
  [bndwrap] valid class files regardless of compile errors.
  [bndwrap] The following package(s) import from the default package
[org.apache.naming.factory.webservices, org.apache.catalina.startup]

BUILD FAILED
/Users/christopherschultz/git/tomcat-trunk/build.xml:852: The
following error occurred while executing this line:
/Users/christopherschultz/git/tomcat-trunk/build.xml:3372: The
following error occurred while executing this line:
/Users/christopherschultz/git/tomcat-trunk/build.xml:3381: Failed to
wrap jar file

Downgrading to Java 8 (as per Tomcat 10 build instructions) yields the
same result.

What am I missing?

Thanks,
- -chris
-BEGIN PGP SIGNATURE-
Comment: Using GnuPG with Thunderbird - https://www.enigmail.net/

iQIzBAEBCAAdFiEEMmKgYcQvxMe7tcJcHPApP6U8pFgFAl5evpsACgkQHPApP6U8
pFiGcRAAkaGS2G+/DCXQbByimPYmCWbWWtq3pZPICjW4CpZA12Gx03Kr9Jo5jJTe
3ygSN8WxZTkfArtrcg0bop44FuYJZU7owPbP5ppDt38q7R3bI0einB+KKTsBuu4l
tsfDipRV6ItzjbIY/UJNJho4/go0vaIcmkQU8KtQf5CI/zZiDWJq1RkQmxSQkc0r
hMWy2YLAigsSikR1Aah8fOn8WICNEKYOylsUmFVr119Ps6SgkYQ+Vq0+UGSo1UWW
+yP6hhCqJaK/WIyJBr3n4As8QRzZ9w+n+H6BZmUiH+iQMgURYkTvicTqkcewFOPE
r6lh5AGDYKJiGRtA8k0uqweOT1mwtIEN7T2OeDG4axXAIVeW5PSAT6O5ZibWRL7p
ZDITx8ZpZpNvzixOaGm1Nqy7xzd5c/vXwyckvM/phZp/UnLxnFYkZkjqtO14tYQc
FcNjeBZjIJxP7lPhfLXpMRI1Lf5sQy1lnhZOg3dqVChJEWCabpz/wZscsUSV1LCa
G05RbMj9JsrDo3Y9jI+9ixWy6t+C3HFGJ4WqayVwd+ErdDjanEIsUO48lTKwD+be
iz07aP8LMUVSholwhu1kR1YsaWb6mL+Y3f5AeitCBnkiAW2ZvBSAX9knsAFkrhUq
EkAm9brjvmz44QJ+eUdVJLEY1GXAIUt1rAELtdjt/n/3E1cdvPw=
=N/et
-END PGP SIGNATURE-

-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



[Bug 64192] Bug in Tomcat HTTP2 POST - with big payload

2020-03-03 Thread bugzilla
https://bz.apache.org/bugzilla/show_bug.cgi?id=64192

--- Comment #3 from Mark Thomas  ---
I think that might be a red herring. I think it is an artefact of client
buffering. I've seen similar behaviour with Chrome.

I'm currently looking at SecureNioChannel.read(ByteBuffer,int,int). I've been
adding various debug logging and I think I have tracked it down to this method.
Still looking for a root cause.

-- 
You are receiving this mail because:
You are the assignee for the bug.
-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



[Bug 64192] Bug in Tomcat HTTP2 POST - with big payload

2020-03-03 Thread bugzilla
https://bz.apache.org/bugzilla/show_bug.cgi?id=64192

--- Comment #4 from Mark Thomas  ---
There is a bug there (in the number of bytes returned) but not the root cause
of this issue. I have a quick fix for SecureNioChannel that I'll look at
refining once I've tracked down the root cause.

-- 
You are receiving this mail because:
You are the assignee for the bug.
-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



Re: [VOTE] Release Apache Tomcat Connectors (JK) 1.2.48

2020-03-03 Thread Rainer Jung

Am 20.02.2020 um 17:55 schrieb Mark Thomas:

Tag:
https://gitbox.apache.org/repos/asf?p=tomcat-connectors.git;a=commit;h=90b294ce8260ab2585dcb4071ede5d53e51fa354

Source:
https://gitbox.apache.org/repos/asf?p=tomcat-connectors.git;a=summary

Dist:
https://dist.apache.org/repos/dist/dev/tomcat/tomcat-connectors/jk/


This is a maintenance release with a handful of bug fixes (compared to
1.2.46) and some clean-up. It also includes Windows binaries for IIS.


The proposed JK 1.2.48 release is:
[ ] Broken - do not release
[X] Stable - go ahead and release as 1.2.48


I have minor remarks mostly related to release artefacts:

- the src archive files in previous versions contained files CHANGES and 
NEWS in the native directory. They are generated by our release skript, 
which searches for any of w3m, elinks, links or lynx. Maybe none of 
those existed on the original build system for those artefacts. The 
files do get generated when I run the release skript for 1.2.48 locally.


- the symbol archive files in earlier versions contained a file README. 
I think it originates from native/iis/README.


- at least in some "printer" html docs links have changed by one level. 
E.g. docs/common_howto/printer/loadbalancers.html in 1.2.46 contains a 
link to ../../reference/workers.html in 1.2.46 and 
../reference/workers.html in 1.2.48. There are two workers reference 
pages, docs/reference/printer/workers.html and 
docs/reference/workers.html. So the 1.2.46 link should work but jump 
from the "printer" docs to the normal page. The 1.2.48 should no longer 
work at all.


Thanks a bunch for RM!

Regards,

Rainer

-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org